@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,6 +44,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.java.Strings;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.User;
@@ -126,8 +127,7 @@ public final class ParallelsInfoServlet extends PermissionServlet {
 
         String login = session.getLogin();
 
-        final String[] tmp = login.split("@");
-        login = tmp[0];
+        login = Strings.splitBy(login, '@', true)[0];
         final String password = session.getPassword();
         final int contextid = session.getContextId();
         String context_name = "UNRESOLVED";
